==> apigateway-1.27.0-sources.jar: software/amazon/awscdk/services/apigateway/Deployment.java <==
package software.amazon.awscdk.services.apigateway;

/**
 * A Deployment of a REST API.
 * <p>
 * An immutable representation of a RestApi resource that can be called by users
 * using Stages. A deployment must be associated with a Stage for it to be
 * callable over the Internet.
 * <p>
 * Normally, you don't need to define deployments manually. The RestApi
 * construct manages a Deployment resource that represents the latest model. It
 * can be accessed through <code>restApi.latestDeployment</code> (unless <code>deploy: false</code> is
 * set when defining the <code>RestApi</code>).
 * <p>
 * If you manually define this resource, you will need to know that since
 * deployments are immutable, as long as the resource's logical ID doesn't
 * change, the deployment will represent the snapshot in time in which the
 * resource was created. This means that if you modify the RestApi model (i.e.
 * add methods or resources), these changes will not be reflected unless a new
 * deployment resource is created.
 * <p>
 * To achieve this behavior, the method <code>addToLogicalId(data)</code> can be used to
 * augment the logical ID generated for the deployment resource such that it
 * will include arbitrary data. This is done automatically for the
 * <code>restApi.latestDeployment</code> deployment.
 * <p>
 * Furthermore, since a deployment does not reference any of the REST API
 * resources and methods, CloudFormation will likely provision it before these
 * resources are created, which means that it will represent a "half-baked"
 * model. Use the <code>node.addDependency(dep)</code> method to circumvent that. This is done
 * automatically for the <code>restApi.latestDeployment</code> deployment.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.22.0 (build 14afdde)", date = "2020-03-03T11:43:25.934Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.apigateway.$Module.class, fqn = "@aws-cdk/aws-apigateway.Deployment")
public class Deployment extends software.amazon.awscdk.core.Resource {

    protected Deployment(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Deployment(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public Deployment(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.apigateway.DeploymentProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * Adds a component to the hash that determines this Deployment resource's logical ID.
     * <p>
     * This should be called by constructs of the API Gateway model that want to
     * invalidate the deployment when their settings change. The component will
     * be resolve()ed during synthesis so tokens are welcome.
     * <p>
     * @param data This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void addToLogicalId(final @org.jetbrains.annotations.NotNull java.lang.Object data) {
        this.jsiiCall("addToLogicalId", software.amazon.jsii.NativeType.VOID, new Object[] { data });
    }

    /**
     * Hook into synthesis before it occurs and make any final adjustments.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    protected void prepare() {
        this.jsiiCall("prepare", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.apigateway.IRestApi getApi() {
        return this.jsiiGet("api", software.amazon.awscdk.services.apigateway.IRestApi.class);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getDeploymentId() {
        return this.jsiiGet("deploymentId", java.lang.String.class);
    }

    /**
     * A fluent builder for {@link software.amazon.awscdk.services.apigateway.Deployment}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param id This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.amazon.awscdk.core.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awscdk.services.apigateway.DeploymentProps.Builder props;

        private Builder(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awscdk.services.apigateway.DeploymentProps.Builder();
        }

        /**
         * The Rest API to deploy.
         * <p>
         * @return {@code this}
         * @param api The Rest API to deploy. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder api(final software.amazon.awscdk.services.apigateway.IRestApi api) {
            this.props.api(api);
            return this;
        }

        /**
         * A description of the purpose of the API Gateway deployment.
         * <p>
         * Default: - No description.
         * <p>
         * @return {@code this}
         * @param description A description of the purpose of the API Gateway deployment. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder description(final java.lang.String description) {
            this.props.description(description);
            return this;
        }

        /**
         * When an API Gateway model is updated, a new deployment will automatically be created.
         * <p>
         * If this is true (default), the old API Gateway Deployment resource will not be deleted.
         * This will allow manually reverting back to a previous deployment in case for example
         * <p>
         * Default: false
         * <p>
         * @return {@code this}
         * @param retainDeployments When an API Gateway model is updated, a new deployment will automatically be created. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder retainDeployments(final java.lang.Boolean retainDeployments) {
            this.props.retainDeployments(retainDeployments);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.services.apigateway.Deployment}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public software.amazon.awscdk.services.apigateway.Deployment build() {
            return new software.amazon.awscdk.services.apigateway.Deployment(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}

==> apigateway-1.29.0-sources.jar: software/amazon/awscdk/services/apigateway/Deployment.java <==
package software.amazon.awscdk.services.apigateway;

/**
 * A Deployment of a REST API.
 * <p>
 * An immutable representation of a RestApi resource that can be called by users
 * using Stages. A deployment must be associated with a Stage for it to be
 * callable over the Internet.
 * <p>
 * Normally, you don't need to define deployments manually. The RestApi
 * construct manages a Deployment resource that represents the latest model. It
 * can be accessed through <code>restApi.latestDeployment</code> (unless <code>deploy: false</code> is
 * set when defining the <code>RestApi</code>).
 * <p>
 * If you manually define this resource, you will need to know that since
 * deployments are immutable, as long as the resource's logical ID doesn't
 * change, the deployment will represent the snapshot in time in which the
 * resource was created. This means that if you modify the RestApi model (i.e.
 * add methods or resources), these changes will not be reflected unless a new
 * deployment resource is created.
 * <p>
 * To achieve this behavior, the method <code>addToLogicalId(data)</code> can be used to
 * augment the logical ID generated for the deployment resource such that it
 * will include arbitrary data. This is done automatically for the
 * <code>restApi.latestDeployment</code> deployment.
 * <p>
 * Furthermore, since a deployment does not reference any of the REST API
 * resources and methods, CloudFormation will likely provision it before these
 * resources are created, which means that it will represent a "half-baked"
 * model. Use the <code>node.addDependency(dep)</code> method to circumvent that. This is done
 * automatically for the <code>restApi.latestDeployment</code> deployment.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.22.0 (build 14afdde)", date = "2020-03-18T10:30:32.836Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.apigateway.$Module.class, fqn = "@aws-cdk/aws-apigateway.Deployment")
public class Deployment extends software.amazon.awscdk.core.Resource {

    protected Deployment(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Deployment(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public Deployment(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.apigateway.DeploymentProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * Adds a component to the hash that determines this Deployment resource's logical ID.
     * <p>
     * This should be called by constructs of the API Gateway model that want to
     * invalidate the deployment when their settings change. The component will
     * be resolve()ed during synthesis so tokens are welcome.
     * <p>
     * @param data This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void addToLogicalId(final @org.jetbrains.annotations.NotNull java.lang.Object data) {
        this.jsiiCall("addToLogicalId", software.amazon.jsii.NativeType.VOID, new Object[] { data });
    }

    /**
     * Hook into synthesis before it occurs and make any final adjustments.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    protected void prepare() {
        this.jsiiCall("prepare", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.apigateway.IRestApi getApi() {
        return this.jsiiGet("api", software.amazon.awscdk.services.apigateway.IRestApi.class);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getDeploymentId() {
        return this.jsiiGet("deploymentId", java.lang.String.class);
    }

    /**
     * A fluent builder for {@link software.amazon.awscdk.services.apigateway.Deployment}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param id This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.amazon.awscdk.core.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awscdk.services.apigateway.DeploymentProps.Builder props;

        private Builder(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awscdk.services.apigateway.DeploymentProps.Builder();
        }

        /**
         * The Rest API to deploy.
         * <p>
         * @return {@code this}
         * @param api The Rest API to deploy. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder api(final software.amazon.awscdk.services.apigateway.IRestApi api) {
            this.props.api(api);
            return this;
        }

        /**
         * A description of the purpose of the API Gateway deployment.
         * <p>
         * Default: - No description.
         * <p>
         * @return {@code this}
         * @param description A description of the purpose of the API Gateway deployment. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder description(final java.lang.String description) {
            this.props.description(description);
            return this;
        }

        /**
         * When an API Gateway model is updated, a new deployment will automatically be created.
         * <p>
         * If this is true, the old API Gateway Deployment resource will not be deleted.
         * This will allow manually reverting back to a previous deployment in case for example
         * <p>
         * Default: false
         * <p>
         * @return {@code this}
         * @param retainDeployments When an API Gateway model is updated, a new deployment will automatically be created. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder retainDeployments(final java.lang.Boolean retainDeployments) {
            this.props.retainDeployments(retainDeployments);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.services.apigateway.Deployment}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public software.amazon.awscdk.services.apigateway.Deployment build() {
            return new software.amazon.awscdk.services.apigateway.Deployment(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}
